@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to hundreds of possible chord progressions
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use strict;
 use warnings;
@@ -75,7 +75,7 @@ Data::Dataset::ChordProgressions - Provide access to hundreds of possible chord
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,16 @@ version 0.0101
 =head1 DESCRIPTION
 
 C<Data::Dataset::ChordProgressions> provides access to hundreds of
-possible chord progressions.
+possible musical chord progressions in five genres: C<blues>,
+C<country>, C<jazz>, C<pop> and C<rock>.  Each has progressions in
+keys of C<C major> and C<C minor>.
+
+Each of these is divided into a C<type> of progression, depending on
+song position.  Take these types with a grain of salt.  They may or
+may not be meaningful...
+
+Each of these is a list of possible chord progressions by named chords
+and by Roman numeral notation.
 
 =head1 FUNCTIONS
 
